from pyramid.view import view_config


@view_config(route_name="home", renderer="templates/index.jinja2")
def home(request):
    return {}


@view_config(route_name="burgerprofiel", renderer="templates/burgerprofiel.jinja2")
def header_footer(request):
    return {}


@view_config(route_name="burgerprofiel2", renderer="templates/burgerprofiel2.jinja2")
def header_footer2(request):
    return {}


@view_config(route_name="headerlinks", renderer="templates/headerlinks.jinja2")
def headerlinks(request):
    return {}


@view_config(route_name="grids", renderer="templates/grids.jinja2")
def grids(request):
    return {}


@view_config(route_name="beeldbank", renderer="templates/beeldbank/beeldbank.jinja2")
def beeldbank(request):
    return {}


@view_config(
    route_name="besluitendatabank", renderer="templates/besluitendatabank.jinja2"
)
def besluitendatabank(request):
    return {}


@view_config(route_name="beheersplannen", renderer="templates/beheersplannen.jinja2")
def beheersplannen(request):
    return {}


@view_config(
    route_name="beheersplannenres", renderer="templates/beheersplannen/result.jinja2"
)
def beheersplannenres(request):
    return {}


@view_config(route_name="actorenfront", renderer="templates/actorenfront.jinja2")
def actorenfront(request):
    return {}


@view_config(
    route_name="detail-bedrijf", renderer="templates/actorenfront/detail-bedrijf.jinja2"
)
def actorenfrontdetailbedrijf(request):
    return {}


@view_config(
    route_name="detail-bedrijfv2",
    renderer="templates/actorenfront/detail-bedrijfv2.jinja2",
)
def actorenfrontdetailbedrijfv2(request):
    return {}


@view_config(route_name="detail", renderer="templates/actorenfront/detail.jinja2")
def actorenfrontdetail(request):
    return {}


@view_config(route_name="actorenzoek", renderer="templates/actorenzoek.jinja2")
def actorenzoek(request):
    return {}


@view_config(
    route_name="actorenzoekdetail", renderer="templates/actorenzoek/detail.jinja2"
)
def actorenzoekdetail(request):
    return {}


@view_config(
    route_name="beeldbank-detail",
    renderer="templates/beeldbank/beeldbank-detail.jinja2",
)
def beeldbank_detail(request):
    return {}


@view_config(
    route_name="beeldbank-zoeken",
    renderer="templates/beeldbank/beeldbank-uitgebreid-zoeken.jinja2",
)
def beeldbank_zoeken(request):
    return {}


@view_config(route_name="inventaris", renderer="templates/inventaris/inventaris.jinja2")
def inventaris(request):
    return {}


@view_config(
    route_name="inventaris-article",
    renderer="templates/inventaris/inventaris-article.jinja2",
)
def inventaris_article(request):
    return {}


@view_config(
    route_name="inventaris-articleID",
    renderer="templates/inventaris/inventaris-articleID.jinja2",
)
def inventaris_articleID(request):
    return {}


@view_config(
    route_name="inventaris-articleIDv2",
    renderer="templates/inventaris/inventaris-articleIDv2.jinja2",
)
def inventaris_articleIDv2(request):
    return {}


@view_config(
    route_name="inventaris-articleIDfull",
    renderer="templates/inventaris/inventaris-articleIDfull.jinja2",
)
def inventaris_articleIDfull(request):
    return {}


@view_config(
    route_name="inventaris-articleIDfullv2",
    renderer="templates/inventaris/inventaris-articleIDfullv2.jinja2",
)
def inventaris_articleIDfullv2(request):
    return {}


@view_config(
    route_name="inventaris-articleIDfullv3",
    renderer="templates/inventaris/inventaris-articleIDfullv3.jinja2",
)
def inventaris_articleIDfullv3(request):
    return {}


@view_config(
    route_name="inventaris-zoekoverzicht",
    renderer="templates/inventaris/inventaris-zoekoverzicht.jinja2",
)
def inventaris_zoekoverzicht(request):
    return {}


@view_config(
    route_name="postregistratie", renderer="templates/postregistratie/index.jinja2"
)
def postregistratie(request):
    return {}


@view_config(
    route_name="postreg-aanmaken", renderer="templates/postregistratie/aanmaken.jinja2"
)
def postreg_aanmaken(request):
    return {}


@view_config(route_name="icons", renderer="templates/icons.jinja2")
def icons(request):
    return {}


@view_config(route_name="blokken", renderer="templates/blokken.jinja2")
def blokken(request):
    return {}


@view_config(route_name="typo", renderer="templates/typo.jinja2")
def typo(request):
    return {}


@view_config(route_name="navigation", renderer="templates/navigation.jinja2")
def navigation(request):
    return {}


@view_config(route_name="colors", renderer="templates/colors.jinja2")
def colors(request):
    return {}


@view_config(route_name="elements", renderer="templates/elements.jinja2")
def elements(request):
    return {}


@view_config(route_name="images", renderer="templates/images.jinja2")
def images(request):
    return {}


@view_config(route_name="article", renderer="templates/article.jinja2")
def article(request):
    return {}


@view_config(route_name="article9-3", renderer="templates/article9-3.jinja2")
def article93(request):
    return {}


@view_config(route_name="geoportaal", renderer="templates/geoportaal/geoportaal.jinja2")
def geoportaal(request):
    return {}


@view_config(route_name="pinpoints", renderer="templates/pinpoints.jinja2")
def pinpoints(request):
    return {}


@view_config(route_name="401", renderer="templates/401.jinja2")
def viernuleen(request):
    return {}


@view_config(route_name="403", renderer="templates/403.jinja2")
def viernuldrie(request):
    return {}


@view_config(route_name="404", renderer="templates/404.jinja2")
def viernulvier(request):
    return {}


@view_config(route_name="500", renderer="templates/500.jinja2")
def vijfhonderd(request):
    return {}


@view_config(route_name="atramhasismenu", renderer="templates/atramhasis_menu.jinja2")
def atramhasismenu(request):
    return {}



import os

from pyramid.response import FileResponse
from pyramid.view import view_config


class StaticView(object):
    """
    Views voor aan de root gebonden static files.
    """

    def __init__(self, request):
        self.request = request
        self.here = os.path.dirname(__file__)

    @view_config(name="favicon.ico")
    def faviconico(self):
        """
        View om een statische favicon.ico te kunnen serveren
        """
        icon = os.path.join(self.here, "static", "favicon.ico")
        return FileResponse(icon, request=self.request)

    @view_config(name="robots.txt")
    def robotstxt(self):
        """
        View om een statische robots.txt te kunnen serveren
        """
        icon = os.path.join(self.here, "static", "robots.txt")
        return FileResponse(icon, request=self.request)



# -*- coding: utf8 -*-
import unittest

from pyoes.utils import (
    _fuzzy_date_formatter,
    datetime_format_filter,
    fuzzy_date_format_filter,
    set_attr_filter,
)


class TestSetAttr(unittest.TestCase):
    def test_set_attr_filter(self):
        d = {}
        d2 = set_attr_filter(d, "pagina", 1)
        self.assertEqual({"pagina": 1}, d2)

    def test_set_attr_filter_overwrites(self):
        d = {"pagina": 1}
        d2 = set_attr_filter(d, "pagina", 10)
        self.assertEqual({"pagina": 10}, d2)


class TestDatetimeFormatFilter(unittest.TestCase):
    def test_datetime_format_filter_default(self):
        from datetime import datetime

        d = datetime(2014, 9, 7, 20, 00)
        fd = datetime_format_filter(d)
        self.assertEqual("07-09-2014 20:00", fd)

    def test_datetime_format_filter_date(self):
        from datetime import date

        d = date(2014, 9, 7)
        fd = datetime_format_filter(d, format="%d-%m-%Y")
        self.assertEqual("07-09-2014", fd)

    def test_datetime_format_filter_custom_format(self):
        from datetime import datetime

        d = datetime(2014, 9, 7, 20, 00)
        fd = datetime_format_filter(d, "%d-%m-%Y")
        self.assertEqual("07-09-2014", fd)

    def test_datetime_format_filter_default_parsed(self):
        fd = datetime_format_filter("07-09-2014 20:00")
        self.assertEqual("07-09-2014 20:00", fd)

    def test_datetime_format_filter_yearfirst(self):
        fd = datetime_format_filter("2017-01-26")
        self.assertEqual("26-01-2017 00:00", fd)

    def test_datetime_format_filter_yearfirst_daylast(self):
        fd = datetime_format_filter("2017-11-12")
        self.assertEqual("12-11-2017 00:00", fd)

    def test_datetime_format_filter_yearfirst_slash(self):
        fd = datetime_format_filter("2017/11/12")
        self.assertEqual("12-11-2017 00:00", fd)

    def test_datetime_format_filter_slash(self):
        fd = datetime_format_filter("12/11/12")
        self.assertEqual("12-11-2012 00:00", fd)

    def test_datetime_format_filter_none(self):
        fd = datetime_format_filter(None)
        self.assertEqual("", fd)


class TestFuzzyDateFormatFilter(unittest.TestCase):
    def test_fuzzy_date_format_filter_default(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = fuzzy_date_format_filter(d)
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_format_filter_before_1900(self):
        from datetime import datetime

        d = datetime(1782, 4, 26, 20, 00)
        fd = fuzzy_date_format_filter(d)
        self.assertEqual("26-04-1782", fd)

    def test_fuzzy_date_format_filter_date(self):
        from datetime import date

        d = date(2018, 4, 26)
        fd = fuzzy_date_format_filter(d)
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_format_filter_custom_format(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = fuzzy_date_format_filter(d, "%m-%Y")
        self.assertEqual("04-2018", fd)
        d = datetime(2018, 4, 26, 20, 00)
        fd = fuzzy_date_format_filter(d, "%Y")
        self.assertEqual("2018", fd)

    def test_fuzzy_date_format_filter_default_parsed(self):
        fd = fuzzy_date_format_filter("26-04-2018 20:00")
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_format_filter_yearfirst(self):
        fd = fuzzy_date_format_filter("2018-04-26")
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_format_filter_yearfirst_daylast(self):
        fd = fuzzy_date_format_filter("2018-11-12")
        self.assertEqual("12-11-2018", fd)

    def test_fuzzy_date_format_filter_yearfirst_slash(self):
        fd = fuzzy_date_format_filter("2018/11/12")
        self.assertEqual("12-11-2018", fd)

    def test_fuzzy_date_format_filter_slash(self):
        fd = fuzzy_date_format_filter("12/11/12")
        self.assertEqual("12-11-2012", fd)

    def test_fuzzy_date_format_filter_none(self):
        fd = fuzzy_date_format_filter(None)
        self.assertEqual("", fd)

    def test_fuzzy_date_formatter_default(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = _fuzzy_date_formatter(d)
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_formatter_day_month_year(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = _fuzzy_date_formatter(d, "%d-%m-%Y")
        self.assertEqual("26-04-2018", fd)

    def test_fuzzy_date_formatter_month_year(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = _fuzzy_date_formatter(d, "%m-%Y")
        self.assertEqual("04-2018", fd)

    def test_fuzzy_date_formatter_year(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = _fuzzy_date_formatter(d, "%Y")
        self.assertEqual("2018", fd)

    def test_fuzzy_date_formatter_not_defined_formar(self):
        from datetime import datetime

        d = datetime(2018, 4, 26, 20, 00)
        fd = _fuzzy_date_formatter(d, "%Y-%d-%m")
        self.assertEqual("26-04-2018", fd)



# -*- coding: utf-8 -*-

from pyramid.config import Configurator


def main(global_config, **settings):  # pragma: no cover
    """
    Returns a pyramid application that can help demo the style.
    """
    config = Configurator(settings=settings)
    config.add_static_view("static", "static", cache_max_age=3600)
    config.add_route("home", "/")
    config.add_route("burgerprofiel", "/burgerprofiel")
    config.add_route("burgerprofiel2", "/burgerprofiel2")
    config.add_route("headerlinks", "/headerlinks")
    config.add_route("grids", "/grids")
    config.add_route("beeldbank", "/beeldbank")
    config.add_route("beheersplannen", "/beheersplannen")
    config.add_route("beheersplannenres", "/beheersplannen/result")
    config.add_route("actorenfront", "/actorenfront")
    config.add_route("detail-bedrijf", "/actorenfront/detail-bedrijf")
    config.add_route("detail-bedrijfv2", "/actorenfront/detail-bedrijfv2")
    config.add_route("detail", "/actorenfront/detail")
    config.add_route("actorenzoek", "/actorenzoek")
    config.add_route("actorenzoekdetail", "/actorenzoek/detail")
    config.add_route("beeldbank-detail", "/beeldbank-detail")
    config.add_route("beeldbank-zoeken", "/beeldbank-zoeken")
    config.add_route("besluitendatabank", "/besluitendatabank")
    config.add_route("inventaris", "/inventaris")
    config.add_route("inventaris-article", "/inventaris-article")
    config.add_route("inventaris-articleID", "/inventaris-articleID")
    config.add_route("inventaris-articleIDv2", "/inventaris-articleIDv2")
    config.add_route("inventaris-articleIDfull", "/inventaris-articleIDfull")
    config.add_route("inventaris-articleIDfullv2", "/inventaris-articleIDfullv2")
    config.add_route("inventaris-articleIDfullv3", "/inventaris-articleIDfullv3")
    config.add_route("inventaris-zoekoverzicht", "/inventaris-zoekoverzicht")
    config.add_route("postregistratie", "/postregistratie")
    config.add_route("postreg-aanmaken", "/postregistratie/aanmaken")
    config.add_route("icons", "/icons")
    config.add_route("blokken", "/blokken")
    config.add_route("typo", "/typo")
    config.add_route("navigation", "/navigation")
    config.add_route("colors", "/colors")
    config.add_route("elements", "/elements")
    config.add_route("images", "/images")
    config.add_route("article", "/article")
    config.add_route("article9-3", "/article9-3")
    config.add_route("geoportaal", "/geoportaal")
    config.add_route("pinpoints", "/pinpoints")
    config.add_route("401", "/401")
    config.add_route("403", "/403")
    config.add_route("404", "/404")
    config.add_route("500", "/500")
    config.add_route("atramhasismenu", "/atramhasismenu")

    includeme(config)

    config.scan("pyoes.views")
    return config.make_wsgi_app()


def includeme(config):
    """
    Include pyoes in a pyramid application.

    :param pyramid.config.Configurator config:
    """

    config.add_static_view("pyoes_static", "pyoes:static")
    config.scan("pyoes.static_views")

    return config



from pyramid.scaffolds import PyramidTemplate


class PyoesTemplate(PyramidTemplate):
    _template_dir = "pyoes_scaffold"
    summary = "Een scaffold om een pyramid project uit te breiden met OE stijl\
    bestanden op basis van sass en compass."


class PyoesAdminTemplate(PyramidTemplate):
    _template_dir = "pyoes_admin_scaffold"
    summary = "Een scaffold om een de admin interface van een\
            pyramid project uit te breiden met OE stijl\
            bestanden op basis van sass en compass."


class PyoesProcesTemplate(PyramidTemplate):
    _template_dir = "pyoes_proces_scaffold"
    summary = "Een scaffold om een de proces interface van een pyramid\
            project uit te breiden met OE stijl\
            bestanden op basis van sass en compass."



# -*- coding: utf8 -*-

from __future__ import unicode_literals

from pyramid import testing

from pyoes import includeme


class TestIncludeMe:

    def test_includeme(self):
        config = testing.setUp()
        includeme(config)
        del config



import unittest

from pyramid import testing
from pyramid.response import FileResponse


class StaticViewTests(unittest.TestCase):

    def _get_static_view(self, request):
        from pyoes.static_views import StaticView

        return StaticView(request)

    def test_robotstxt(self):
        request = testing.DummyRequest()
        sv = self._get_static_view(request)
        res = sv.robotstxt()
        self.assertIsInstance(res, FileResponse)
        self.assertEqual("text/plain", res.content_type)

    def test_faviconico(self):
        request = testing.DummyRequest()
        sv = self._get_static_view(request)
        res = sv.faviconico()
        self.assertIsInstance(res, FileResponse)
        assert res.content_type in ["image/x-icon", "image/vnd.microsoft.icon"]



# -*- coding: utf-8 -*-
"""
Contains some extra filters for Jinja2.

To use these, they need to be registered in your pyramid config.
"""
from dateutil import parser


def set_attr_filter(target, key, value):
    """
    Jinja2 filter that sets an attribute of an object.
    """
    target[key] = value
    return target


def datetime_format_filter(value, format="%d-%m-%Y %H:%M"):
    """
    Jinja 2 filter to print a datetime object in a template.

    :param value: Eiter a :class:`datetime.datetime` or a string that can be \
        parsed by :class:`dateutil.parser`. In case of ambiguity between the \
        day and the month, the parser will assume the day precedes the month \
        (ie. European way)
    :param format: The format to print the date in.
    :return: The formatted date, eg. `07-09-2014 20:00`.
    """
    if value:
        try:
            return value.strftime(format)
        except AttributeError:
            if value[0:4].find("-") == -1 and value[0:4].find("/") == -1:
                date = parser.parse(value, yearfirst=True, dayfirst=False)
            else:
                date = parser.parse(value, dayfirst=True)
            return date.strftime(format)
    else:
        return ""


def fuzzy_date_format_filter(value, format="%d-%m-%Y"):
    """
    Jinja 2 filter to print a fuzzy date object in a template.

    :param value: Eiter a :class:`datetime.datetime` or a string that can be \
        parsed by :class:`dateutil.parser`. In case of ambiguity between the \
        day and the month, the parser will assume the day precedes the month \
        (ie. European way)
    :param format: The format to print the date in.
    :return: The formatted date, eg. `07-09-2014 20:00`.
    """
    if value:
        try:
            return _fuzzy_date_formatter(value, format)
        except AttributeError:
            if value[0:4].find("-") == -1 and value[0:4].find("/") == -1:
                date = parser.parse(value, yearfirst=True, dayfirst=False)
            else:
                date = parser.parse(value, dayfirst=True)
            return _fuzzy_date_formatter(date, format)
    else:
        return ""


def _fuzzy_date_formatter(date, format="%d-%m-%Y"):
    """
    Dateconverter to convert date or datetime objects to strings in a specific format

    Implemented because of the problems of datetime.strftime method with years before 1900
    :param date:
    :param format: The format to print the date in. (must be a predefined format)
                    '%d-%m-%Y' or '%m-%Y' or '%Y'
    :return: The formatted date, eg. `07-09-2014`
    """
    if format == "%d-%m-%Y":
        return "{0.day:02d}-{0.month:02d}-{0.year:4d}".format(date)
    elif format == "%m-%Y":
        return "{0.month:02d}-{0.year:4d}".format(date)
    elif format == "%Y":
        return "{0.year:4d}".format(date)
    else:
        # Default
        return "{0.day:02d}-{0.month:02d}-{0.year:4d}".format(date)
